@@ -24,6 +24,47 @@ from bm_ext import *
 __all__ = ["BitVector", "strat"]
 
 class BitVector(object):
+	"""
+	>>> v = BitVector()
+	>>> v.resize(64)
+	>>> for i in range(32): v[i*2] = True
+	...
+	>>> print v
+        <BitVector 10101010101010101010101010101010...>
+	>>> print v[0], v[1]
+	True False
+	>>>
+	### the length and number of bits that are set
+	>>> print len(v), v.count()
+	64 32
+	>>>
+	### bitwise NOT
+	>>> u = ~v
+	>>> print u
+	<BitVector 01010101010101010101010101010101...>
+	>>>
+	### bitwise AND
+	>>> print v&u
+        <BitVector 00000000000000000000000000000000...>
+	>>>
+	### bitwise OR
+	>>> print v|u
+	<BitVector 11111111111111111111111111111111...>
+	>>>
+	### iteration
+	>>> v = BitVector()
+	>>> v.resize(10)
+	>>> for i in range(5): v[i*2] = True
+	...
+	>>> for k in v: print k
+	...
+	0
+	2
+	4
+	6
+	8
+	>>>
+	"""
 	def __init__(self, v = None):
 		if v is None:
 			v = bvector()
@@ -31,6 +72,7 @@ class BitVector(object):
 		self.__vector__ = v
 
 		self.count = v.count
+		self.size = v.size
 		self.resize = v.resize
 		self.capacity = v.capacity
 
@@ -44,6 +86,31 @@ class BitVector(object):
 		self.deserialize = v.deserialize
 		self.set_new_blocks_strat = v.set_new_blocks_strat
 
+	def __str__(self):
+		def _s():
+			i = 0
+			g = iter(self)
+			size = len(self)
+			max_size = 32
+			while i < min(max_size, size):
+				try:
+					one = g.next()
+					zeros = min(max_size, one) - i
+					if zeros > 0:
+						yield "0"*zeros
+						i = i + zeros 
+					if one < max_size: 
+						yield "1"
+					i = i + 1
+				except StopIteration:
+					zeros = min(max_size, size) - i
+					if zeros > 0:
+						yield "0"*zeros
+						i = i + zeros
+			if i < size:
+				yield "..."
+		return "<BitVector %s>" % ("".join(_s()),)
+					
 	def __len__(self):
 		return len(self.__vector__)
 	def __setitem__(self, k, v):
@@ -85,3 +152,7 @@ class BitVector(object):
 		print "Bit blocks:".rjust(25), st.bit_blocks
 		print "GAP blocks:".rjust(25), st.gap_blocks
 		print "Memory used:".rjust(25), "%.02fMB" % (float(st.memory_used) / 1024 / 1024)
+
+if __name__ == '__main__':
+	import doctest
+	doctest.testmod()
