@@ -1,14 +1,13 @@
-from bm_nose import BitVectorTest
 from bm import BitVector
 from sys import stdout
 
-class TestClass(BitVectorTest):
+class TestClass:
 	def test_count(self):
 		base = 2
 		exp = 18
 		size = base ** exp
 
-		for e in range(exp):
+		for e in range(exp+1):
 			v = BitVector()
 			div = base ** (exp-e)
 			nbits = size / div
